import { select, min, max, scaleLinear, mean} from 'd3';

import { dropDownMenu } from './dropDownMenu';

const width = document.body.clientWidth;
const height = document.body.clientHeight;

const svg = select('svg')
    .attr('width', width)
    .attr('height', height);

svg
  .append('rect')
    .attr('width', width)
    .attr('height', height)
    .attr('rx', 40)

const x = width / 2;
const y = height / 2;
const m = min([x, y]) - 70;

const value = d => Math.sqrt(d);
const opts = ['First aircraft', 'Second aircraft']
let xColumn = opts[0];

const onXColumnClicked = column => {
  xColumn = column;  
	render(aircrafts[xColumn]);
};

const aircrafts = {};
  aircrafts[opts[0]] = [
    3, 5, 7, 18, 43, 85, 91, 98, 100, 130, 230, 487
  ];
  aircrafts[opts[1]] = [
    3,5,5,13,14,15,22,22,23,30,36,39,
    44,56,50,72,79,88,97,102,139,188,197,210
  ];

select('div.choice')
  .call(dropDownMenu, {
    options: opts,
    onOptionClicked: onXColumnClicked,
    selectedOption: xColumn
});
  
const render = data => {
  let avg = mean(data);
  const maxRadius = max(data, value);
  const scale = scaleLinear()
    .domain([0, maxRadius])
    .range([0, m]);
  
  let circles = svg.selectAll('circle').data(data);

  circles
    .enter().append('circle')
       .attr('cx', x)
       .attr('cy', y)
       .attr('r', scale(value(avg)))
       .attr('fill', 'none')
       .attr('stroke','white')
       .attr('stroke-width','1px')
    .merge(circles)
    .transition().duration(1000)
       .attr('r', d => scale(value(d)));

  circles.exit()
    .transition().duration(1500)
      .attr('r', 0)
    .remove();

  let circleAvg = svg.selectAll('circle.avg').data([avg]);
  circleAvg
    .enter().append('circle')
       .attr('class', 'avg')
       .attr('cx', x)
       .attr('cy', y)
       .attr('fill', 'none')
       .attr('stroke','yellow')
       .attr('stroke-width','3px')
    .merge(circleAvg)
    .transition().duration(2000)
       .attr('r', scale(value(avg)))
}

render(aircrafts[xColumn]);